@@ -13,7 +13,7 @@ BEGIN {
 
 use Graph::AdjacencyMap qw(:flags :fields);
 
-our $VERSION = '0.9708';
+our $VERSION = '0.9709';
 
 require 5.006; # Weak references are absolutely required.
 
@@ -1373,7 +1373,7 @@ sub has_vertex_attribute_by_id {
 sub get_vertex_attributes {
     my $g = shift;
     $g->expect_non_multivertexed;
-    return unless $g->has_vertex( @_ );
+    return undef unless $g->has_vertex( @_ );
     my $a = $g->[ _V ]->_get_path_attrs( @_ );
     ($g->is_compat02) ? (defined $a ? %{ $a } : ()) : $a;
 }
@@ -1552,7 +1552,7 @@ sub has_edge_attribute_by_id {
 sub get_edge_attributes {
     my $g = shift;
     $g->expect_non_multiedged;
-    return unless $g->has_edge( @_ );
+    return undef unless $g->has_edge( @_ );
     my $a = $g->[ _E ]->_get_path_attrs( $g->_vertex_ids( @_ ) );
     ($g->is_compat02) ? (defined $a ? %{ $a } : ()) : $a;
 }
@@ -1734,6 +1734,24 @@ sub rename_vertices {
     return $g;
 }
 
+sub as_hashes {
+    my ($g) = @_;
+    my %e;
+    $e{ $_->[0] }{ $_->[1] } = $g->get_edge_attributes(@$_) || {} for $g->edges;
+    my %n = map +( $_ => $g->get_vertex_attributes($_) || {} ), $g->vertices;
+    ( \%n, \%e );
+}
+
+sub ingest {
+    my ($g, $g2) = @_;
+    for my $v ($g2->vertices) {
+        $g->set_vertex_attributes($v, $g2->get_vertex_attributes($v));
+        $g->set_edge_attributes(@$_, $g2->get_edge_attributes(@$_))
+            for $g2->edges_from($v);
+    }
+    $g;
+}
+
 ###
 # More constructors.
 #
